pub struct LoggingLayer {
pub verbosity: LogVerbosity,
pub slow_threshold_ms: u64,
}Expand description
Tower Layer that wraps a service with request/response logging.
Fields
verbosity: LogVerbosityVerbosity level.
slow_threshold_ms: u64Threshold in milliseconds above which Brief verbosity logs the request.
Implementations
Sourceimpl LoggingLayer
impl LoggingLayer
Sourcepub fn new(verbosity: LogVerbosity) -> Self
pub fn new(verbosity: LogVerbosity) -> Self
Construct a LoggingLayer with the given verbosity and a default slow
threshold of 100 ms.
Sourcepub fn with_slow_threshold(self, ms: u64) -> Self
pub fn with_slow_threshold(self, ms: u64) -> Self
Override the slow-request threshold (milliseconds).